@@ -3,11 +3,9 @@
 """Tests for `aoba_discord_bot` package."""
 
 import pytest
-
 from click.testing import CliRunner
 
-from aoba_discord_bot import bot
-from aoba_discord_bot import cli
+from aoba_discord_bot import bot, cli
 
 
 @pytest.fixture
@@ -29,9 +27,5 @@ def test_content(response):
 def test_command_line_interface():
     """Test the CLI."""
     runner = CliRunner()
-    result = runner.invoke(cli.main)
-    assert result.exit_code == 0
-    assert "aoba_discord_bot.cli.main" in result.output
     help_result = runner.invoke(cli.main, ["--help"])
     assert help_result.exit_code == 0
-    assert "--help  Show this message and exit." in help_result.output
